/* Automatically generated by tree-sitter v0.25.1 (f5afe475deb7c0bae6407fb776c76824f717bb61) */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 83
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 27
#define ALIAS_COUNT 0
#define TOKEN_COUNT 16
#define EXTERNAL_TOKEN_COUNT 10
#define FIELD_COUNT 5
#define MAX_ALIAS_SEQUENCE_LENGTH 7
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 13
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_COLON = 1,
  anon_sym_EQ = 2,
  anon_sym_PIPE = 3,
  sym_reference = 4,
  sym__ws = 5,
  sym__line_end = 6,
  sym__indent = 7,
  sym__continue = 8,
  sym__dedent = 9,
  sym_identifier = 10,
  sym_text_start = 11,
  sym_text_fragment = 12,
  sym_string = 13,
  sym_comment = 14,
  sym_error = 15,
  sym_source_file = 16,
  sym_object = 17,
  sym_section = 18,
  sym_body = 19,
  sym_struct_row = 20,
  sym_table_row = 21,
  sym_text = 22,
  aux_sym_source_file_repeat1 = 23,
  aux_sym_body_repeat1 = 24,
  aux_sym_table_row_repeat1 = 25,
  aux_sym_text_repeat1 = 26,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_COLON] = ":",
  [anon_sym_EQ] = "=",
  [anon_sym_PIPE] = "|",
  [sym_reference] = "reference",
  [sym__ws] = "_ws",
  [sym__line_end] = "_line_end",
  [sym__indent] = "_indent",
  [sym__continue] = "_continue",
  [sym__dedent] = "_dedent",
  [sym_identifier] = "identifier",
  [sym_text_start] = "text_fragment",
  [sym_text_fragment] = "text_fragment",
  [sym_string] = "string",
  [sym_comment] = "comment",
  [sym_error] = "error",
  [sym_source_file] = "source_file",
  [sym_object] = "object",
  [sym_section] = "section",
  [sym_body] = "body",
  [sym_struct_row] = "struct_row",
  [sym_table_row] = "table_row",
  [sym_text] = "text",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_body_repeat1] = "body_repeat1",
  [aux_sym_table_row_repeat1] = "table_row_repeat1",
  [aux_sym_text_repeat1] = "text_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [sym_reference] = sym_reference,
  [sym__ws] = sym__ws,
  [sym__line_end] = sym__line_end,
  [sym__indent] = sym__indent,
  [sym__continue] = sym__continue,
  [sym__dedent] = sym__dedent,
  [sym_identifier] = sym_identifier,
  [sym_text_start] = sym_text_fragment,
  [sym_text_fragment] = sym_text_fragment,
  [sym_string] = sym_string,
  [sym_comment] = sym_comment,
  [sym_error] = sym_error,
  [sym_source_file] = sym_source_file,
  [sym_object] = sym_object,
  [sym_section] = sym_section,
  [sym_body] = sym_body,
  [sym_struct_row] = sym_struct_row,
  [sym_table_row] = sym_table_row,
  [sym_text] = sym_text,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_body_repeat1] = aux_sym_body_repeat1,
  [aux_sym_table_row_repeat1] = aux_sym_table_row_repeat1,
  [aux_sym_text_repeat1] = aux_sym_text_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [sym_reference] = {
    .visible = true,
    .named = true,
  },
  [sym__ws] = {
    .visible = false,
    .named = true,
  },
  [sym__line_end] = {
    .visible = false,
    .named = true,
  },
  [sym__indent] = {
    .visible = false,
    .named = true,
  },
  [sym__continue] = {
    .visible = false,
    .named = true,
  },
  [sym__dedent] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_text_start] = {
    .visible = true,
    .named = true,
  },
  [sym_text_fragment] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_error] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_object] = {
    .visible = true,
    .named = true,
  },
  [sym_section] = {
    .visible = true,
    .named = true,
  },
  [sym_body] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_row] = {
    .visible = true,
    .named = true,
  },
  [sym_table_row] = {
    .visible = true,
    .named = true,
  },
  [sym_text] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_table_row_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_text_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_base = 1,
  field_body = 2,
  field_key = 3,
  field_name = 4,
  field_value = 5,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_base] = "base",
  [field_body] = "body",
  [field_key] = "key",
  [field_name] = "name",
  [field_value] = "value",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 2},
  [2] = {.index = 2, .length = 3},
  [3] = {.index = 5, .length = 2},
  [5] = {.index = 7, .length = 3},
  [6] = {.index = 10, .length = 2},
  [7] = {.index = 12, .length = 1},
  [8] = {.index = 13, .length = 3},
  [9] = {.index = 16, .length = 2},
  [10] = {.index = 18, .length = 2},
  [11] = {.index = 20, .length = 2},
  [12] = {.index = 22, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_base, 0},
    {field_name, 2},
  [2] =
    {field_base, 0},
    {field_body, 4},
    {field_name, 2},
  [5] =
    {field_base, 0},
    {field_name, 3},
  [7] =
    {field_base, 0},
    {field_body, 5},
    {field_name, 3},
  [10] =
    {field_base, 0},
    {field_name, 4},
  [12] =
    {field_name, 0},
  [13] =
    {field_base, 0},
    {field_body, 6},
    {field_name, 4},
  [16] =
    {field_body, 2},
    {field_name, 0},
  [18] =
    {field_key, 0},
    {field_value, 2},
  [20] =
    {field_key, 0},
    {field_value, 3},
  [22] =
    {field_key, 0},
    {field_value, 4},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [4] = {
    [0] = sym_text_fragment,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 2,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 9,
  [17] = 10,
  [18] = 18,
  [19] = 19,
  [20] = 11,
  [21] = 12,
  [22] = 22,
  [23] = 23,
  [24] = 13,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 19,
  [29] = 29,
  [30] = 15,
  [31] = 26,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 38,
  [41] = 32,
  [42] = 34,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 37,
  [52] = 52,
  [53] = 35,
  [54] = 54,
  [55] = 39,
  [56] = 56,
  [57] = 57,
  [58] = 33,
  [59] = 59,
  [60] = 60,
  [61] = 56,
  [62] = 62,
  [63] = 62,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 60,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 70,
  [74] = 68,
  [75] = 64,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 78,
  [80] = 80,
  [81] = 72,
  [82] = 82,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(2);
      if (lookahead == '\r') SKIP(0);
      if (lookahead == ':') ADVANCE(3);
      if (lookahead == '=') ADVANCE(4);
      if (lookahead == '[') ADVANCE(1);
      if (lookahead == '|') ADVANCE(5);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(7);
      END_STATE();
    case 1:
      if (lookahead == ']') ADVANCE(6);
      if (lookahead != 0) ADVANCE(1);
      END_STATE();
    case 2:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 3:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 4:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 5:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 6:
      ACCEPT_TOKEN(sym_reference);
      END_STATE();
    case 7:
      ACCEPT_TOKEN(sym__ws);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(7);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 0, .external_lex_state = 2},
  [2] = {.lex_state = 0, .external_lex_state = 3},
  [3] = {.lex_state = 0, .external_lex_state = 3},
  [4] = {.lex_state = 0, .external_lex_state = 3},
  [5] = {.lex_state = 0, .external_lex_state = 3},
  [6] = {.lex_state = 0, .external_lex_state = 4},
  [7] = {.lex_state = 0, .external_lex_state = 4},
  [8] = {.lex_state = 0, .external_lex_state = 4},
  [9] = {.lex_state = 0, .external_lex_state = 5},
  [10] = {.lex_state = 0, .external_lex_state = 5},
  [11] = {.lex_state = 0, .external_lex_state = 5},
  [12] = {.lex_state = 0, .external_lex_state = 5},
  [13] = {.lex_state = 0, .external_lex_state = 5},
  [14] = {.lex_state = 0, .external_lex_state = 2},
  [15] = {.lex_state = 0, .external_lex_state = 6},
  [16] = {.lex_state = 0, .external_lex_state = 7},
  [17] = {.lex_state = 0, .external_lex_state = 7},
  [18] = {.lex_state = 0, .external_lex_state = 2},
  [19] = {.lex_state = 0, .external_lex_state = 6},
  [20] = {.lex_state = 0, .external_lex_state = 7},
  [21] = {.lex_state = 0, .external_lex_state = 7},
  [22] = {.lex_state = 0, .external_lex_state = 4},
  [23] = {.lex_state = 0, .external_lex_state = 4},
  [24] = {.lex_state = 0, .external_lex_state = 7},
  [25] = {.lex_state = 0, .external_lex_state = 4},
  [26] = {.lex_state = 0, .external_lex_state = 6},
  [27] = {.lex_state = 0, .external_lex_state = 8},
  [28] = {.lex_state = 0, .external_lex_state = 9},
  [29] = {.lex_state = 0, .external_lex_state = 9},
  [30] = {.lex_state = 0, .external_lex_state = 9},
  [31] = {.lex_state = 0, .external_lex_state = 9},
  [32] = {.lex_state = 0, .external_lex_state = 10},
  [33] = {.lex_state = 0, .external_lex_state = 2},
  [34] = {.lex_state = 0, .external_lex_state = 2},
  [35] = {.lex_state = 0, .external_lex_state = 2},
  [36] = {.lex_state = 0, .external_lex_state = 10},
  [37] = {.lex_state = 0, .external_lex_state = 2},
  [38] = {.lex_state = 0, .external_lex_state = 10},
  [39] = {.lex_state = 0, .external_lex_state = 2},
  [40] = {.lex_state = 0, .external_lex_state = 10},
  [41] = {.lex_state = 0, .external_lex_state = 10},
  [42] = {.lex_state = 0, .external_lex_state = 10},
  [43] = {.lex_state = 0, .external_lex_state = 11},
  [44] = {.lex_state = 0, .external_lex_state = 11},
  [45] = {.lex_state = 0, .external_lex_state = 11},
  [46] = {.lex_state = 0, .external_lex_state = 10},
  [47] = {.lex_state = 0, .external_lex_state = 10},
  [48] = {.lex_state = 0, .external_lex_state = 10},
  [49] = {.lex_state = 0, .external_lex_state = 10},
  [50] = {.lex_state = 0, .external_lex_state = 10},
  [51] = {.lex_state = 0, .external_lex_state = 10},
  [52] = {.lex_state = 0, .external_lex_state = 11},
  [53] = {.lex_state = 0, .external_lex_state = 10},
  [54] = {.lex_state = 0, .external_lex_state = 11},
  [55] = {.lex_state = 0, .external_lex_state = 10},
  [56] = {.lex_state = 0, .external_lex_state = 12},
  [57] = {.lex_state = 0, .external_lex_state = 11},
  [58] = {.lex_state = 0, .external_lex_state = 10},
  [59] = {.lex_state = 0, .external_lex_state = 10},
  [60] = {.lex_state = 0, .external_lex_state = 11},
  [61] = {.lex_state = 0, .external_lex_state = 12},
  [62] = {.lex_state = 0, .external_lex_state = 12},
  [63] = {.lex_state = 0, .external_lex_state = 12},
  [64] = {.lex_state = 0, .external_lex_state = 8},
  [65] = {.lex_state = 0, .external_lex_state = 11},
  [66] = {.lex_state = 0, .external_lex_state = 8},
  [67] = {.lex_state = 0, .external_lex_state = 8},
  [68] = {.lex_state = 0, .external_lex_state = 8},
  [69] = {.lex_state = 0, .external_lex_state = 8},
  [70] = {.lex_state = 0, .external_lex_state = 8},
  [71] = {.lex_state = 0, .external_lex_state = 11},
  [72] = {.lex_state = 0, .external_lex_state = 12},
  [73] = {.lex_state = 0, .external_lex_state = 8},
  [74] = {.lex_state = 0, .external_lex_state = 8},
  [75] = {.lex_state = 0, .external_lex_state = 8},
  [76] = {.lex_state = 0, .external_lex_state = 8},
  [77] = {.lex_state = 0, .external_lex_state = 11},
  [78] = {.lex_state = 0, .external_lex_state = 12},
  [79] = {.lex_state = 0, .external_lex_state = 12},
  [80] = {.lex_state = 0, .external_lex_state = 8},
  [81] = {.lex_state = 0, .external_lex_state = 12},
  [82] = {.lex_state = 0, .external_lex_state = 11},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [sym_reference] = ACTIONS(1),
    [sym__ws] = ACTIONS(1),
    [sym__line_end] = ACTIONS(1),
    [sym__indent] = ACTIONS(1),
    [sym__continue] = ACTIONS(1),
    [sym__dedent] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [sym_text_start] = ACTIONS(1),
    [sym_text_fragment] = ACTIONS(1),
    [sym_string] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_error] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(82),
    [sym_object] = STATE(18),
    [aux_sym_source_file_repeat1] = STATE(18),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym__line_end] = ACTIONS(7),
    [sym_identifier] = ACTIONS(9),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_PIPE,
    ACTIONS(15), 1,
      sym__line_end,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_text_start,
    STATE(43), 1,
      aux_sym_table_row_repeat1,
    STATE(80), 1,
      sym_text,
    ACTIONS(13), 2,
      sym_string,
      sym_reference,
    STATE(38), 4,
      sym_object,
      sym_section,
      sym_struct_row,
      sym_table_row,
  [32] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_PIPE,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_text_start,
    ACTIONS(21), 1,
      sym__line_end,
    STATE(43), 1,
      aux_sym_table_row_repeat1,
    STATE(80), 1,
      sym_text,
    ACTIONS(13), 2,
      sym_string,
      sym_reference,
    STATE(59), 4,
      sym_object,
      sym_section,
      sym_struct_row,
      sym_table_row,
  [64] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_PIPE,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_text_start,
    ACTIONS(23), 1,
      sym__line_end,
    STATE(43), 1,
      aux_sym_table_row_repeat1,
    STATE(80), 1,
      sym_text,
    ACTIONS(13), 2,
      sym_string,
      sym_reference,
    STATE(40), 4,
      sym_object,
      sym_section,
      sym_struct_row,
      sym_table_row,
  [96] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym__ws,
    ACTIONS(29), 1,
      sym__line_end,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_text_start,
    STATE(44), 1,
      sym_text,
    ACTIONS(25), 2,
      sym_string,
      sym_reference,
  [119] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym_text_start,
    ACTIONS(35), 1,
      sym__ws,
    ACTIONS(37), 1,
      sym_identifier,
    STATE(66), 1,
      sym_text,
    ACTIONS(13), 2,
      sym_string,
      sym_reference,
  [139] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      sym__ws,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_text_start,
    STATE(44), 1,
      sym_text,
    ACTIONS(25), 2,
      sym_string,
      sym_reference,
  [159] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym_text_start,
    ACTIONS(37), 1,
      sym_identifier,
    ACTIONS(39), 1,
      sym__ws,
    STATE(76), 1,
      sym_text,
    ACTIONS(13), 2,
      sym_string,
      sym_reference,
  [179] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(11), 1,
      aux_sym_text_repeat1,
    ACTIONS(41), 2,
      anon_sym_PIPE,
      sym__ws,
    ACTIONS(43), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [195] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(12), 1,
      aux_sym_text_repeat1,
    ACTIONS(45), 2,
      anon_sym_PIPE,
      sym__ws,
    ACTIONS(47), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [211] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(13), 1,
      aux_sym_text_repeat1,
    ACTIONS(49), 2,
      anon_sym_PIPE,
      sym__ws,
    ACTIONS(51), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [227] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(13), 1,
      aux_sym_text_repeat1,
    ACTIONS(53), 2,
      anon_sym_PIPE,
      sym__ws,
    ACTIONS(51), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [243] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(13), 1,
      aux_sym_text_repeat1,
    ACTIONS(55), 2,
      anon_sym_PIPE,
      sym__ws,
    ACTIONS(57), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [259] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(60), 1,
      ts_builtin_sym_end,
    ACTIONS(62), 1,
      sym__line_end,
    ACTIONS(65), 1,
      sym_identifier,
    STATE(14), 2,
      sym_object,
      aux_sym_source_file_repeat1,
  [276] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(70), 1,
      sym__indent,
    STATE(35), 1,
      sym_body,
    ACTIONS(68), 3,
      sym__line_end,
      sym_identifier,
      ts_builtin_sym_end,
  [291] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      sym__line_end,
    STATE(20), 1,
      aux_sym_text_repeat1,
    ACTIONS(72), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [306] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      sym__line_end,
    STATE(21), 1,
      aux_sym_text_repeat1,
    ACTIONS(74), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [321] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_identifier,
    ACTIONS(76), 1,
      ts_builtin_sym_end,
    ACTIONS(78), 1,
      sym__line_end,
    STATE(14), 2,
      sym_object,
      aux_sym_source_file_repeat1,
  [338] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(70), 1,
      sym__indent,
    STATE(34), 1,
      sym_body,
    ACTIONS(80), 3,
      sym__line_end,
      sym_identifier,
      ts_builtin_sym_end,
  [353] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      sym__line_end,
    STATE(24), 1,
      aux_sym_text_repeat1,
    ACTIONS(82), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [368] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym__line_end,
    STATE(24), 1,
      aux_sym_text_repeat1,
    ACTIONS(82), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [383] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      sym_identifier,
    ACTIONS(33), 1,
      sym_text_start,
    STATE(45), 1,
      sym_text,
    ACTIONS(25), 2,
      sym_string,
      sym_reference,
  [400] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym_text_start,
    ACTIONS(37), 1,
      sym_identifier,
    STATE(76), 1,
      sym_text,
    ACTIONS(13), 2,
      sym_string,
      sym_reference,
  [417] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      sym__line_end,
    STATE(24), 1,
      aux_sym_text_repeat1,
    ACTIONS(84), 3,
      sym_text_fragment,
      sym_string,
      sym_reference,
  [432] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      sym_text_start,
    ACTIONS(37), 1,
      sym_identifier,
    STATE(67), 1,
      sym_text,
    ACTIONS(13), 2,
      sym_string,
      sym_reference,
  [449] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(70), 1,
      sym__indent,
    STATE(37), 1,
      sym_body,
    ACTIONS(87), 3,
      sym__line_end,
      sym_identifier,
      ts_builtin_sym_end,
  [464] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      sym__line_end,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(91), 1,
      anon_sym_EQ,
    ACTIONS(93), 1,
      sym__ws,
  [480] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(95), 1,
      sym__indent,
    STATE(42), 1,
      sym_body,
    ACTIONS(80), 2,
      sym__continue,
      sym__dedent,
  [494] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(95), 1,
      sym__indent,
    STATE(46), 1,
      sym_body,
    ACTIONS(97), 2,
      sym__continue,
      sym__dedent,
  [508] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(95), 1,
      sym__indent,
    STATE(53), 1,
      sym_body,
    ACTIONS(68), 2,
      sym__continue,
      sym__dedent,
  [522] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(95), 1,
      sym__indent,
    STATE(51), 1,
      sym_body,
    ACTIONS(87), 2,
      sym__continue,
      sym__dedent,
  [536] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(99), 1,
      sym__continue,
    ACTIONS(101), 1,
      sym__dedent,
    STATE(36), 1,
      aux_sym_body_repeat1,
  [549] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(103), 3,
      sym__line_end,
      sym_identifier,
      ts_builtin_sym_end,
  [558] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(105), 3,
      sym__line_end,
      sym_identifier,
      ts_builtin_sym_end,
  [567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(107), 3,
      sym__line_end,
      sym_identifier,
      ts_builtin_sym_end,
  [576] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(109), 1,
      sym__continue,
    ACTIONS(112), 1,
      sym__dedent,
    STATE(36), 1,
      aux_sym_body_repeat1,
  [589] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(114), 3,
      sym__line_end,
      sym_identifier,
      ts_builtin_sym_end,
  [598] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(99), 1,
      sym__continue,
    ACTIONS(116), 1,
      sym__dedent,
    STATE(32), 1,
      aux_sym_body_repeat1,
  [611] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(118), 3,
      sym__line_end,
      sym_identifier,
      ts_builtin_sym_end,
  [620] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(99), 1,
      sym__continue,
    ACTIONS(120), 1,
      sym__dedent,
    STATE(41), 1,
      aux_sym_body_repeat1,
  [633] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(99), 1,
      sym__continue,
    ACTIONS(122), 1,
      sym__dedent,
    STATE(36), 1,
      aux_sym_body_repeat1,
  [646] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(105), 2,
      sym__continue,
      sym__dedent,
  [654] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(124), 1,
      anon_sym_PIPE,
    STATE(54), 1,
      aux_sym_table_row_repeat1,
  [664] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(126), 1,
      anon_sym_PIPE,
    ACTIONS(128), 1,
      sym__ws,
  [674] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(130), 1,
      anon_sym_PIPE,
    ACTIONS(132), 1,
      sym__ws,
  [684] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(134), 2,
      sym__continue,
      sym__dedent,
  [692] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(136), 2,
      sym__continue,
      sym__dedent,
  [700] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(138), 2,
      sym__continue,
      sym__dedent,
  [708] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(140), 2,
      sym__continue,
      sym__dedent,
  [716] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(142), 2,
      sym__continue,
      sym__dedent,
  [724] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(114), 2,
      sym__continue,
      sym__dedent,
  [732] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(144), 1,
      anon_sym_COLON,
    ACTIONS(146), 1,
      sym__ws,
  [742] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(107), 2,
      sym__continue,
      sym__dedent,
  [750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(148), 1,
      anon_sym_PIPE,
    STATE(54), 1,
      aux_sym_table_row_repeat1,
  [760] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(118), 2,
      sym__continue,
      sym__dedent,
  [768] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(151), 1,
      sym__ws,
    ACTIONS(153), 1,
      sym_identifier,
  [778] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(155), 1,
      anon_sym_COLON,
    ACTIONS(157), 1,
      anon_sym_EQ,
  [788] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(103), 2,
      sym__continue,
      sym__dedent,
  [796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(112), 2,
      sym__continue,
      sym__dedent,
  [804] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 2,
      anon_sym_PIPE,
      sym__ws,
  [812] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(159), 1,
      sym__ws,
    ACTIONS(161), 1,
      sym_identifier,
  [822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(163), 1,
      sym__ws,
    ACTIONS(165), 1,
      sym_identifier,
  [832] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(167), 1,
      sym__ws,
    ACTIONS(169), 1,
      sym_identifier,
  [842] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(171), 1,
      sym__line_end,
  [849] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(173), 1,
      anon_sym_PIPE,
  [856] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(175), 1,
      sym__line_end,
  [863] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(177), 1,
      sym__line_end,
  [870] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(179), 1,
      sym__line_end,
  [877] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      sym__line_end,
  [884] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(181), 1,
      sym__line_end,
  [891] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(183), 1,
      anon_sym_COLON,
  [898] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(185), 1,
      sym_identifier,
  [905] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(187), 1,
      sym__line_end,
  [912] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(189), 1,
      sym__line_end,
  [919] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(191), 1,
      sym__line_end,
  [926] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(193), 1,
      sym__line_end,
  [933] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(130), 1,
      anon_sym_PIPE,
  [940] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(169), 1,
      sym_identifier,
  [947] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(165), 1,
      sym_identifier,
  [954] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(195), 1,
      sym__line_end,
  [961] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(197), 1,
      sym_identifier,
  [968] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(199), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 32,
  [SMALL_STATE(4)] = 64,
  [SMALL_STATE(5)] = 96,
  [SMALL_STATE(6)] = 119,
  [SMALL_STATE(7)] = 139,
  [SMALL_STATE(8)] = 159,
  [SMALL_STATE(9)] = 179,
  [SMALL_STATE(10)] = 195,
  [SMALL_STATE(11)] = 211,
  [SMALL_STATE(12)] = 227,
  [SMALL_STATE(13)] = 243,
  [SMALL_STATE(14)] = 259,
  [SMALL_STATE(15)] = 276,
  [SMALL_STATE(16)] = 291,
  [SMALL_STATE(17)] = 306,
  [SMALL_STATE(18)] = 321,
  [SMALL_STATE(19)] = 338,
  [SMALL_STATE(20)] = 353,
  [SMALL_STATE(21)] = 368,
  [SMALL_STATE(22)] = 383,
  [SMALL_STATE(23)] = 400,
  [SMALL_STATE(24)] = 417,
  [SMALL_STATE(25)] = 432,
  [SMALL_STATE(26)] = 449,
  [SMALL_STATE(27)] = 464,
  [SMALL_STATE(28)] = 480,
  [SMALL_STATE(29)] = 494,
  [SMALL_STATE(30)] = 508,
  [SMALL_STATE(31)] = 522,
  [SMALL_STATE(32)] = 536,
  [SMALL_STATE(33)] = 549,
  [SMALL_STATE(34)] = 558,
  [SMALL_STATE(35)] = 567,
  [SMALL_STATE(36)] = 576,
  [SMALL_STATE(37)] = 589,
  [SMALL_STATE(38)] = 598,
  [SMALL_STATE(39)] = 611,
  [SMALL_STATE(40)] = 620,
  [SMALL_STATE(41)] = 633,
  [SMALL_STATE(42)] = 646,
  [SMALL_STATE(43)] = 654,
  [SMALL_STATE(44)] = 664,
  [SMALL_STATE(45)] = 674,
  [SMALL_STATE(46)] = 684,
  [SMALL_STATE(47)] = 692,
  [SMALL_STATE(48)] = 700,
  [SMALL_STATE(49)] = 708,
  [SMALL_STATE(50)] = 716,
  [SMALL_STATE(51)] = 724,
  [SMALL_STATE(52)] = 732,
  [SMALL_STATE(53)] = 742,
  [SMALL_STATE(54)] = 750,
  [SMALL_STATE(55)] = 760,
  [SMALL_STATE(56)] = 768,
  [SMALL_STATE(57)] = 778,
  [SMALL_STATE(58)] = 788,
  [SMALL_STATE(59)] = 796,
  [SMALL_STATE(60)] = 804,
  [SMALL_STATE(61)] = 812,
  [SMALL_STATE(62)] = 822,
  [SMALL_STATE(63)] = 832,
  [SMALL_STATE(64)] = 842,
  [SMALL_STATE(65)] = 849,
  [SMALL_STATE(66)] = 856,
  [SMALL_STATE(67)] = 863,
  [SMALL_STATE(68)] = 870,
  [SMALL_STATE(69)] = 877,
  [SMALL_STATE(70)] = 884,
  [SMALL_STATE(71)] = 891,
  [SMALL_STATE(72)] = 898,
  [SMALL_STATE(73)] = 905,
  [SMALL_STATE(74)] = 912,
  [SMALL_STATE(75)] = 919,
  [SMALL_STATE(76)] = 926,
  [SMALL_STATE(77)] = 933,
  [SMALL_STATE(78)] = 940,
  [SMALL_STATE(79)] = 947,
  [SMALL_STATE(80)] = 954,
  [SMALL_STATE(81)] = 961,
  [SMALL_STATE(82)] = 968,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [41] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 1, 0, 4),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [45] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 1, 0, 0),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [49] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 2, 0, 4),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [53] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_text, 2, 0, 0),
  [55] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0),
  [57] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(13),
  [60] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [62] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(14),
  [65] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(52),
  [68] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 5, 0, 3),
  [70] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [72] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [74] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [76] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [78] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [80] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 6, 0, 6),
  [82] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [84] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_text_repeat1, 2, 0, 0), SHIFT_REPEAT(24),
  [87] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 4, 0, 1),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [97] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 2, 0, 7),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body, 4, 0, 0),
  [105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 7, 0, 8),
  [107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 6, 0, 5),
  [109] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(3),
  [112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0),
  [114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 5, 0, 2),
  [116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body, 3, 0, 0),
  [120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_table_row_repeat1, 2, 0, 0),
  [128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_table_row_repeat1, 3, 0, 0),
  [132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_section, 3, 0, 9),
  [136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_row, 3, 0, 0),
  [138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_row, 4, 0, 10),
  [140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_row, 5, 0, 11),
  [142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_row, 6, 0, 12),
  [144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_table_row_repeat1, 2, 0, 0), SHIFT_REPEAT(7),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_table_row_repeat1, 4, 0, 0),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [199] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__line_end = 0,
  ts_external_token__indent = 1,
  ts_external_token__continue = 2,
  ts_external_token__dedent = 3,
  ts_external_token_identifier = 4,
  ts_external_token_text_start = 5,
  ts_external_token_text_fragment = 6,
  ts_external_token_string = 7,
  ts_external_token_comment = 8,
  ts_external_token_error = 9,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__line_end] = sym__line_end,
  [ts_external_token__indent] = sym__indent,
  [ts_external_token__continue] = sym__continue,
  [ts_external_token__dedent] = sym__dedent,
  [ts_external_token_identifier] = sym_identifier,
  [ts_external_token_text_start] = sym_text_start,
  [ts_external_token_text_fragment] = sym_text_fragment,
  [ts_external_token_string] = sym_string,
  [ts_external_token_comment] = sym_comment,
  [ts_external_token_error] = sym_error,
};

static const bool ts_external_scanner_states[13][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__line_end] = true,
    [ts_external_token__indent] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__dedent] = true,
    [ts_external_token_identifier] = true,
    [ts_external_token_text_start] = true,
    [ts_external_token_text_fragment] = true,
    [ts_external_token_string] = true,
    [ts_external_token_comment] = true,
    [ts_external_token_error] = true,
  },
  [2] = {
    [ts_external_token__line_end] = true,
    [ts_external_token_identifier] = true,
    [ts_external_token_comment] = true,
  },
  [3] = {
    [ts_external_token__line_end] = true,
    [ts_external_token_identifier] = true,
    [ts_external_token_text_start] = true,
    [ts_external_token_string] = true,
    [ts_external_token_comment] = true,
  },
  [4] = {
    [ts_external_token_identifier] = true,
    [ts_external_token_text_start] = true,
    [ts_external_token_string] = true,
    [ts_external_token_comment] = true,
  },
  [5] = {
    [ts_external_token_text_fragment] = true,
    [ts_external_token_string] = true,
    [ts_external_token_comment] = true,
  },
  [6] = {
    [ts_external_token__line_end] = true,
    [ts_external_token__indent] = true,
    [ts_external_token_identifier] = true,
    [ts_external_token_comment] = true,
  },
  [7] = {
    [ts_external_token__line_end] = true,
    [ts_external_token_text_fragment] = true,
    [ts_external_token_string] = true,
    [ts_external_token_comment] = true,
  },
  [8] = {
    [ts_external_token__line_end] = true,
    [ts_external_token_comment] = true,
  },
  [9] = {
    [ts_external_token__indent] = true,
    [ts_external_token__continue] = true,
    [ts_external_token__dedent] = true,
    [ts_external_token_comment] = true,
  },
  [10] = {
    [ts_external_token__continue] = true,
    [ts_external_token__dedent] = true,
    [ts_external_token_comment] = true,
  },
  [11] = {
    [ts_external_token_comment] = true,
  },
  [12] = {
    [ts_external_token_identifier] = true,
    [ts_external_token_comment] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_gml_external_scanner_create(void);
void tree_sitter_gml_external_scanner_destroy(void *);
bool tree_sitter_gml_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_gml_external_scanner_serialize(void *, char *);
void tree_sitter_gml_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_gml(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_gml_external_scanner_create,
      tree_sitter_gml_external_scanner_destroy,
      tree_sitter_gml_external_scanner_scan,
      tree_sitter_gml_external_scanner_serialize,
      tree_sitter_gml_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "gml",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 1,
      .patch_version = 1,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
